.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

====================
pyPrediktorUtilities
====================


    Helper functions for Prediktor projects


The included classes and functions allows for easier and more maintainable code when
working with Prediktor projects. The main features are:

* Sending emails
* Working with FTP and SFTP server
* Logging
* Generating files through templates

.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.3. For details and usage
information on PyScaffold see https://pyscaffold.org/.
